@@ -2,7 +2,7 @@ __author__ = 'Altertech, https://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2019 Altertech'
 __license__ = 'MIT'
 
-__version__ = '0.4.7'
+__version__ = '0.4.9'
 
 from sqlalchemy.exc import IntegrityError
 from cachetools import TTLCache
@@ -246,7 +246,7 @@ def _asset_precision(asset=None):
                              code=asset.upper()).fetchone()
         if not d:
             raise ResourceNotFound
-        precs = d.precs
+        precs = int(d.precs)
         asset_precision_cache[asset] = precs
         return precs
     else:
@@ -259,7 +259,7 @@ def _asset_precision(asset=None):
                 if not r: break
                 row = OrderedDict()
                 row['asset'] = r.code
-                row['precision'] = r.precs
+                row['precision'] = int(r.precs)
                 yield row
 
         return all_precs()
@@ -823,13 +823,13 @@ def account_create(account,
             (:account_id, 0, :d, :d)
             """),
                    account_id=acc_id,
-                   d=datetime.datetime.fromtimestamp(0))
+                   d=datetime.datetime(1970, 1, 1))
         db.execute(sql("""
             insert into transact(account_credit_id, amount, d_created, d) values
             (:account_id, 0, :d, :d)
             """),
                    account_id=acc_id,
-                   d=datetime.datetime.fromtimestamp(0))
+                   d=datetime.datetime(1970, 1, 1))
         dbt.commit()
     except IntegrityError:
         dbt.rollback()
@@ -1557,7 +1557,7 @@ def account_statement(account, start=None, end=None, tag=None, pending=True):
         generator object
     """
     acc_info = account_info(account)
-    cond = 'transact.deleted is null and d_created > \'1970-01-02\''
+    cond = 'transact.deleted is null and d_created > \'1970-01-03\''
     d_field = 'd_created' if pending else 'd'
     if start:
         dts = parse_date(start, return_timestamp=False)
